@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 import unittest
-from assembla import API, Ticket
+from assembla import API, Ticket, WikiPage
 from assembla.tests.auth import auth
 
 class TestAssembla(unittest.TestCase):
@@ -52,5 +52,32 @@ class TestAssembla(unittest.TestCase):
         #tidy up (oh and test delete)
         ticket.delete()
 
+    def _get_space_with_wiki_tools(self):
+        for space in self.assembla.spaces():
+            for tool in space.tools():
+                if 'wiki' in tool['menu_name'].lower():
+                    return space
+        raise Exception('Can\'t find a space with the Wiki tool')
+
+    def test_wiki_page_write_and_delete(self):
+        space = self._get_space_with_wiki_tools()
+
+        page_name = 'Test_page'
+
+        wiki_page = WikiPage()
+        wiki_page.space = space
+        wiki_page['page_name'] = page_name
+        wiki_page['contents'] = 'Test content'
+
+        wiki_page = wiki_page.write()
+
+        self.assertTrue(wiki_page['id'])
+
+        self.assertTrue(len(space.wiki_pages(page_name=page_name)) > 0)
+
+        space.wiki_pages(page_name=page_name)[0].delete()
+
+        self.assertTrue(len(space.wiki_pages(page_name=page_name)) == 0)
+
 if __name__ == '__main__':
     unittest.main()
\ No newline at end of file
